@@ -19,4 +19,4 @@
 # OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
 # WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
-from .khalendar import CalendarCollection  # noqa: F401
+from .khalendar import CalendarCollection  # noqa: F401  # type: ignore
